<?php

class ACMS_POST_Image_AjaxUpload extends ACMS_POST_Entry_Update
{
    /**
     * Image upload from ajax
     */
    function post()
    {
        $Entry  = $this->extract('entry');
        $postName = $this->Post->get('post_module_name');
        $Column = null;

        if (preg_match('/^ACMS_POST_Entry_Insert/', $postName)) {
            $Column = $this->insertProcess($Entry);
        } else if (preg_match('/^ACMS_POST_Entry_Update/', $postName)) {
            $Column = $this->updateProcess($Entry);
        }
        if ($Column) {
            die(json_encode($Column));
        }
        die(json_encode(array()));
    }

    /**
     * @param Field $Entry
     * @return int|null|string
     */
    protected function getRange($Entry)
    {
        $range  = strval($Entry->get('summary_range'));
        $range  = ('' === $range) ? null : intval($range);
        return $range;
    }

    /**
     * @param Field $Entry
     * @return mixed
     */
    protected function insertProcess($Entry)
    {
        $range = $this->getRange($Entry);
        $Column = Entry::extractColumn($range);

        return $Column;
    }

    /**
     * @param Field $Entry
     * @return mixed
     */
    protected function updateProcess($Entry)
    {
        //-------------------------------------
        // 公開済み or 承認前 エントリー
        // $preApproval     => 承認前エントリー
        // $updateApproval  => 承認済エントリー
        $preEntry = ACMS_RAM::entry(EID);
        $approvalStatus = $preEntry['entry_approval'];
        $preApproval = enableApproval() && $approvalStatus === 'pre_approval';
        $updateApproval = enableApproval() && $approvalStatus !== 'pre_approval';

        if ( sessionWithApprovalAdministrator() ) {
            $preApproval    = false;
            $updateApproval = false;
        }

        //----------------------------
        // 未来バージョンとして保存フラグ
        $revisionDraft = false;
        if ( 1
            && enableRevision(false)
            && $Entry->get('revision_type') == 'draft_revision'
        ) {
            $revisionDraft = true;
        }
        $moveArchives = false;

        //-----------------------------
        // ユニットファイルを一時的にコピー
        // リビジョンから変更
        if ( RVID && !$updateApproval ) {
            $this->copyUnitArchives(REVISON_ARCHIVES_DIR, ARCHIVES_DIR.'TEMP/');
            $moveArchives = ($revisionDraft) ? 'REVISON_ARCHIVES_DIR' : 'ARCHIVES_DIR';
            // 公開エントリから下書き
        } else if ( $revisionDraft ) {
            $this->copyUnitArchives(ARCHIVES_DIR, ARCHIVES_DIR.'TEMP/');
            $moveArchives = 'REVISON_ARCHIVES_DIR';
            // 承認機能 ON まだエントリが存在しない場合
        } else if ( $preApproval ) {
            $this->copyUnitArchives(REVISON_ARCHIVES_DIR, ARCHIVES_DIR, true);
            // 承認機能 ON エントリ存在
        } else if ( !RVID && $updateApproval ) {
            $this->copyUnitArchives(ARCHIVES_DIR, ARCHIVES_DIR.'TEMP/');
            $moveArchives = 'REVISON_ARCHIVES_DIR';
            // 承認機能 ON リビジョンから変更
        } else if ( RVID && $updateApproval ) {
            $this->copyUnitArchives(REVISON_ARCHIVES_DIR, ARCHIVES_DIR.'TEMP/');
            $moveArchives = 'REVISON_ARCHIVES_DIR';
        }

        $range = $this->getRange($Entry);
        $Column = Entry::extractColumn($range, true, false, $moveArchives);

        return $Column;
    }
}
